@@ -1,6 +1,6 @@
 "law" <-
-structure(list(V1 = c(576, 635, 558, 578, 666, 580, 555, 661, 
-651, 605, 653, 575, 545, 572, 594), V2 = c(339, 330, 281, 303, 
+structure(list(LSAT = c(576, 635, 558, 578, 666, 580, 555, 661, 
+651, 605, 653, 575, 545, 572, 594), GPA = c(339, 330, 281, 303, 
 344, 307, 300, 343, 336, 313, 312, 274, 276, 288, 296)), class = "data.frame", row.names = c("1", 
 "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", 
 "14", "15"))
